@@ -30,7 +30,8 @@ class Timer(threading.Thread):
             
         while True:
             if self.close_thread == True: break #the thread will be closed if the above while: True is broken
-            elif self.is_running == False: continue #won't execute the timer part if the timer is not "started"
+            elif self.is_running == False: #won't execute the timer part if the timer is not "started"
+                sleep(0.2)
         
             self.current_time = 0
             while self.current_time < self.delay: #"current_time" can be greater than the set delay if the delay is a float,
@@ -38,7 +39,7 @@ class Timer(threading.Thread):
                 
                 if self.is_running == False: break #if the stop func is called then break to return to the waiting part
                 
-                self.current_time = self.current_time + self.sleep_time
+                self.current_time = self.current_time + sleep_time
             
             if self.close_thread == True: break
             elif self.is_running == False: continue
